@@ -30,6 +30,7 @@ from pcluster.config.cfn_param_types import (
     HeadNodeAvailabilityZoneCfnParam,
     HeadNodeInstanceTypeCfnParam,
     IntCfnParam,
+    JsonCfnParam,
     MaintainInitialSizeCfnParam,
     NetworkInterfacesCountCfnParam,
     QueueSizeCfnParam,
@@ -57,6 +58,7 @@ from pcluster.config.update_policy import UpdatePolicy
 from pcluster.config.validators import (
     architecture_os_validator,
     base_os_validator,
+    cluster_type_validator,
     cluster_validator,
     compute_instance_type_validator,
     compute_resource_validator,
@@ -98,6 +100,7 @@ from pcluster.config.validators import (
     intel_hpc_os_validator,
     kms_key_validator,
     maintain_initial_size_validator,
+    queue_compute_type_validator,
     queue_settings_validator,
     queue_validator,
     s3_bucket_uri_validator,
@@ -722,7 +725,7 @@ QUEUE = {
     "type": QueueJsonSection,
     "key": "queue",
     "default_label": "default",
-    "validators": [queue_validator],
+    "validators": [queue_validator, queue_compute_type_validator],
     "max_resources": 5,
     "params": OrderedDict([
         ("compute_type", {
@@ -1025,6 +1028,12 @@ CLUSTER_COMMON_PARAMS = [
         "cfn_param_mapping": "IAMLambdaRoleName",
         "update_policy": UpdatePolicy.SUPPORTED,
     }),
+    ("instance_types_data", {
+        "type": JsonCfnParam,
+        "default": {},
+        "cfn_param_mapping": "InstanceTypesData",
+        "update_policy": UpdatePolicy.UNSUPPORTED
+    }),
 ]
 
 
@@ -1096,6 +1105,7 @@ CLUSTER_SIT = {
                 "default": "ondemand",
                 "allowed_values": ["ondemand", "spot"],
                 "cfn_param_mapping": "ClusterType",
+                "validators": [cluster_type_validator],
                 "update_policy": UpdatePolicy.COMPUTE_FLEET_STOP
             }),
             ("spot_price", {
